@@ -12,7 +12,7 @@ class Repository(BaseModel):
     is_archived: bool
     workspace_id: str
     is_public: Optional[bool]
-    git_ssh_pull_link: str
+    remote_path: str
     created_at: str
     updated_at: str
 
